aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--os/ports/GCC/PPC/SPC56ELxx/bam.s4
-rw-r--r--os/ports/GCC/PPC/SPC56ELxx/hwconf.s10
2 files changed, 7 insertions, 7 deletions
diff --git a/os/ports/GCC/PPC/SPC56ELxx/bam.s b/os/ports/GCC/PPC/SPC56ELxx/bam.s
index 54079d311..d4f62795e 100644
--- a/os/ports/GCC/PPC/SPC56ELxx/bam.s
+++ b/os/ports/GCC/PPC/SPC56ELxx/bam.s
@@ -140,8 +140,8 @@
mtspr 529, r31
mtspr 530, r31
- /* MMU configuration.*/
- bl _mmuconf
+ /* HW configuration.*/
+ bl _hwconf
b _boot_address
diff --git a/os/ports/GCC/PPC/SPC56ELxx/hwconf.s b/os/ports/GCC/PPC/SPC56ELxx/hwconf.s
index 3d903e15e..0c1617d69 100644
--- a/os/ports/GCC/PPC/SPC56ELxx/hwconf.s
+++ b/os/ports/GCC/PPC/SPC56ELxx/hwconf.s
@@ -19,8 +19,8 @@
*/
/**
* @file SPC56ELxx/mmuconf.s
* @brief SPC56ELxx MMU initial configuration.
*
* @addtogroup PPC_CORE
* @{
@@ -130,9 +130,9 @@
.section .hwinit, "ax"
.align 2
- .globl _mmuconf
- .type _mmuconf, @function
-_mmuconf:
+ .globl _hwconf
+ .type _hwconf, @function
+_hwconf:
/* TLB0 allocated to flash.*/
e_lis r3, TLB0_MAS0@h
mtspr 624, r3 /* MAS0 */
@@ -19,8 +19,8 @@
*/
/**
- * @file SPC56ELxx/mmuconf.s
- * @brief SPC56ELxx MMU initial configuration.
+ * @file SPC56ELxx/hwconf.s
+ * @brief SPC56ELxx low level hardware configuration.
*
* @addtogroup PPC_CORE